"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const questions = [
    {
        name: 'name',
        message: 'What is the name for your app?',
        type: 'input',
        validate: (name) => /^[a-z0-9-]+$/.test(name) ? true : 'Only use lowercase alphanumeric and -'
    },
    {
        name: 'options',
        message: 'Would you like to use...',
        type: 'checkbox',
        default: ['express', 'gql', 'mongodb', 'router', 'mui', 'vercel'],
        askAnswered: true,
        choices: [
            { value: 'express', name: 'Express?', short: 'express' },
            { value: 'gql', name: 'GraphQL? (Apollo Server/Client)', short: 'graphql' },
            { value: 'mongodb', name: 'MongoDB?', short: 'mongodb' },
            { value: 'router', name: 'React Router', short: 'react-router' },
            { value: 'mui', name: 'Material UI? (mui)', short: 'mui' },
            { value: 'vercel', name: 'Vercel', short: 'vercel' }
        ],
        when: answers => !answers.ci
    },
    {
        name: 'auth',
        message: 'Which Auth Provider would you like to use?',
        type: 'list',
        choices: [
            { value: 'firebase', name: 'Firebase' },
            // Future options: Auth0
            { value: 'jwt', name: 'JSON web token' }
        ],
        when: answers => !answers.ci && answers.options.indexOf('gql') >= 0
    },
    {
        name: 'jwt_auth_secret',
        message: 'Please provide an auth secret for JSON webtoken',
        type: 'input',
        validate: (secret) => secret.length > 0 ? true : false,
        when: answers => !answers.ci && answers.auth === 'jwt'
    },
    {
        name: 'mongo_db_url',
        message: 'Please provide your MongoDB URL for local development',
        type: 'input',
        askAnswered: true,
        default: 'mongodb://127.0.0.1:27017',
        validate: (url) => {
            // TODO: attempt to connect...
            return true;
        },
        when: answers => !answers.ci && answers.options.indexOf('mongodb') >= 0
    },
    {
        name: 'mongo_db_name',
        message: 'Please provide your MongoDB database name',
        type: 'input',
        validate: (name) => {
            // TODO: attempt to connect...
            return true;
        },
        when: answers => !answers.ci && answers.options.indexOf('mongodb') >= 0
    },
    {
        name: 'orm',
        message: 'Would you like to use an ORM?',
        type: 'list',
        default: 'no',
        askAnswered: true,
        choices: [
            { value: 'no', name: 'No' },
            { value: 'mikrorm', name: 'MikrORM' }
        ],
        when: answers => !answers.ci && answers.options.indexOf('mongodb') >= 0
    },
    {
        name: 'port',
        message: 'Which port do you want the server to run on',
        type: 'number',
        default: 3001,
        askAnswered: true,
        when: answers => !answers.ci
    }
];
exports.default = questions;
//# sourceMappingURL=questions.js.map